Documentation
¶
Overview ¶
Package massdns implements the main resolving and wildcard removal logic. It runs the massdns tool, parsing the output file and writing the results to a specified file or output stream like stdout.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsBlankFile ¶
IsBlankFile checks if a file is blank
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client is a client for running massdns on a target
func (*Client) DumpWildcardsToFile ¶
DumpWildcardsToFile dumps the wildcard ips list to file
type Config ¶
type Config struct {
// Domain is the domain specified for enumeration
Domain string
// Retries is the number of retries for dns
Retries int
// MassdnsPath is the path to the binary
MassdnsPath string
// Threads is the hashmap size for massdns
Threads int
// InputFile is the file to use for massdns input
InputFile string
// ResolversFile is the file with the resolvers
ResolversFile string
// TempDir is a temporary directory for storing massdns misc files
TempDir string
// OutputFile is the file to use for massdns output
OutputFile string
// Json is format ouput to ndjson format
Json bool
// WildcardsThreads is the number of wildcards concurrent threads
WildcardsThreads int
// MassdnsRaw perform wildcards filtering from an existing massdns output file
MassdnsRaw string
// StrictWildcard controls whether the wildcard check should be performed on each result
StrictWildcard bool
// WildcardOutputFile is the file where the list of wildcards is dumped
WildcardOutputFile string
}
Config contains configuration options for the massdns client
Click to show internal directories.
Click to hide internal directories.